==> developer-center-api-1.2.19-20161114.050535-2-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/CreateDeveloperParams.java <==
package cn.com.duiba.developer.center.api.domain.paramquery;

import java.io.Serializable;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

/**
 * Created by liuyao on 2016/9/28.
 */
public class CreateDeveloperParams implements Serializable {
    private static final long serialVersionUID = 2797766568005038252L;
    @NotNull
    private String email;
    @NotNull
    @Size(min = 6)
    private String password;
    @NotNull
    private String company;
    @NotNull
    private String name;
    @NotNull
    private String phone;

    private String appName;//第一个App名称,不传,则不会创建

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }
}

==> developer-center-api-3.9.18-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/CreateDeveloperParams.java <==
package cn.com.duiba.developer.center.api.domain.paramquery;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.io.Serializable;

/**
 * Created by liuyao on 2016/9/28.
 */
public class CreateDeveloperParams implements Serializable {
    private static final long serialVersionUID = 2797766568005038252L;

    public static final Integer CREATE_SOURCE_DUIBA = 0;//该条数据来源，0：兑吧；1：推啊，默认为0
    public static final Integer CREATE_SOURCE_TUIA = 1;//该条数据来源，0：兑吧；1：推啊，默认为0

    private String email;
    @NotNull
    @Size(min = 6)
    private String password;
    private String company;
    private String name;
    @NotNull
    private String phone;

    private String appName;//第一个App名称,不传,则不会创建

    private Integer createSource = CREATE_SOURCE_DUIBA;//该条数据来源，0：兑吧 or 1：推啊

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getCreateSource() {
        return createSource;
    }

    public void setCreateSource(Integer createSource) {
        this.createSource = createSource;
    }

}
